aboutsummaryrefslogtreecommitdiffhomepage
path: root/input.h
diff options
context:
space:
mode:
authorGravatar ridiculousfish <corydoras@ridiculousfish.com>2014-07-07 10:45:26 -0700
committerGravatar ridiculousfish <corydoras@ridiculousfish.com>2014-07-07 10:45:26 -0700
commit3915faf3820ad25f326c98c1f7042f9e2670202c (patch)
tree868e2ba5a6677d78023f1404e902befbaac435ab /input.h
parentd5fa4b2ccb27343f1332460b9550391b755a328b (diff)
bind should not show -k for bindings that are escape sequences, not keys
Diffstat (limited to 'input.h')
-rw-r--r--input.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/input.h b/input.h
index b0afe081..1ab43c03 100644
--- a/input.h
+++ b/input.h
@@ -169,8 +169,8 @@ void input_function_set_status(bool status);
*/
bool input_terminfo_get_sequence(const wchar_t *name, wcstring *out_seq);
-/** Return the name of the terminfo variable with the specified sequence */
-bool input_terminfo_get_name(const wcstring &seq, wcstring &name);
+/** Return the name of the terminfo variable with the specified sequence, in out_name. Returns true if found, false if not found. */
+bool input_terminfo_get_name(const wcstring &seq, wcstring *out_name);
/** Return a list of all known terminfo names */
wcstring_list_t input_terminfo_get_names(bool skip_null);